@@ -76,10 +76,14 @@ sub run {
 
   # Remote control commands need to validate arguments carefully
   my $commands = $self->commands;
+  my $kill     = sub {
+    return unless grep { ($_[1] // '') eq $_ } qw(INT KILL USR1 USR2);
+    $self->{jobs}{$_[2]}->kill($_[1]) if $self->{jobs}{$_[2] // ''};
+  };
   local $commands->{jobs}
     = sub { $status->{jobs} = $_[1] if ($_[1] // '') =~ /^\d+$/ };
-  local $commands->{stop}
-    = sub { $self->{jobs}{$_[1]}->stop if $self->{jobs}{$_[1] // ''} };
+  local $commands->{kill} = $kill;
+  local $commands->{stop} = sub { $kill->('KILL', $_[1]) };
 
   eval { $self->_work until $self->{finished} && !keys %{$self->{jobs}} };
   my $err = $@;
@@ -147,7 +151,7 @@ Minion::Worker - Minion worker
 
 L<Minion::Worker> performs jobs for L<Minion>.
 
-=head1 SIGNALS
+=head1 WORKER SIGNALS
 
 The L<Minion::Worker> process can be controlled at runtime with the following
 signals.
@@ -160,6 +164,21 @@ Stop gracefully after finishing the current jobs.
 
 Stop immediately without finishing the current jobs.
 
+=head1 JOB SIGNALS
+
+The job processes spawned by the L<Minion::Worker> process can be controlled at
+runtime with the following signals.
+
+=head2 INT
+
+This signal starts out with the operating system default and allows for jobs to
+install a custom signal handler to stop gracefully.
+
+=head2 USR1, USR2
+
+These signals start out being ignored and allow for jobs to install custom
+signal handlers.
+
 =head1 EVENTS
 
 L<Minion::Worker> inherits all events from L<Mojo::EventEmitter> and can emit
@@ -423,6 +442,15 @@ concurrently. Setting this value to C<0> will effectively pause the worker. That
 means all current jobs will be finished, but no new ones accepted, until the
 number is increased again.
 
+=item kill
+
+  $minion->broadcast('kill', ["INT", 10025]);
+  $minion->broadcast('kill', ["INT", 10025], [$worker_id]);
+
+Instruct one or more workers to send a signal to a job that is currently being
+performed. This command will be ignored by workers that do not have a job
+matching the id. That means it is safe to broadcast this command to all workers.
+
 =item stop
 
   $minion->broadcast('stop', [10025]);
